Filter ExpressionSet by MAS5 presence
filter_mas5.RdFilters probes based on the number of samples where they were called 'Present' (MAS5 algorithm).
Examples
data(eset)
# Filter to keep probes present in at least 12 samples
filtered_eset <- filter_mas5(eset, min_present = 12)