Circadian Liver Microarray Data (GSE11923)
CircadianData.RdThis package provides processed liver transcriptome data from the Hughes et al. (2009) study on circadian rhythms.
Format
Both objects are ExpressionSet objects:
- eset
Normalized, probe-level expression data (GCRMA). Contains 96 samples (48 time points in duplicate). Feature metadata includes gene symbols, gene names, and MAS5 presence/absence calls.
- eset_collapsed
Gene-level expression data. Probes were collapsed to unique gene symbols using the
MaxMeanmethod via WGCNA'scollapseRowsfunction.
An object of class ExpressionSet with 45101 rows and 48 columns.
An object of class ExpressionSet with 21032 rows and 48 columns.